=================
atsphinx-pagefind
=================

Overview
========

.. include:: ../README.rst
   :start-line: 10
   :end-line: 15

Features
========

* Override search page with pagefind components.

Contents
========

.. toctree::
   :maxdepth: 2

   setup
   search-page
   configuration

.. toctree::
   :hidden:

   changes

License
=======

Apache License 2.0.
Please see `it <https://github.com/atsphinx/pagefind/blob/main/LICENSE>`_.
